@@ -1,5 +1,5 @@
 package Defaults::Modern;
-$Defaults::Modern::VERSION = '0.009001';
+$Defaults::Modern::VERSION = '0.009002';
 use v5.14;
 
 use strictures 2;
@@ -195,7 +195,6 @@ Defaults::Modern - Yet another approach to modernistic Perl
 
     # Moo(se) with types ->
     use Moo;
-    use MooX::late;
 
     has myarray => (
       isa => ArrayObj,
@@ -241,7 +240,10 @@ disallowed explicitly (not just in development environments)
 =item *
 
 The C<v5.14> feature set (C<state>, C<say>, C<unicode_strings>, C<array_base>) -- except for
-C<switch>, which is deprecated in newer perls
+C<switch>, which is deprecated in newer perls (and L<Switch::Plain> is
+provided anyway).
+
+C<experimental> warnings are also disabled on C<v5.18+>.
 
 =item *
 
@@ -316,11 +318,11 @@ via L<List::Objects::WithUtils>:
   use Defaults::Modern 'autobox_lists';
   my $itr = [ 1 .. 10 ]->natatime(2);
 
-L<Moo> and L<MooX::late> are depended upon in order to guarantee their
-availability, but not automatically imported:
+L<Moo> version 2+ is depended upon in order to guarantee availability, but not
+automatically imported:
 
   use Defaults::Modern;
-  use Moo;  use MooX::late;
+  use Moo;
 
   has foo => (
     is  => 'ro',
@@ -333,23 +335,6 @@ availability, but not automatically imported:
 L<namespace::sweep> or similar -- L<Defaults::Modern> imports an awful lot of
 Stuff. L<Moops> may be nicer to work with.)
 
-=begin comment
-
- ## Undocumented for now, because Moops is a better solution.
-
-If you import C<Moo>, you get L<Moo> and L<MooX::late> (but you should really
-be using L<Moops> instead):
-
-  use Defaults::Modern 'Moo';
-  has foo => (
-    is      => 'ro',
-    isa     => ArrayObj,
-    coerce  => 1,
-    default => sub { [] },
-  );
-
-=end comment
-
 =head1 SEE ALSO
 
 This package just glues together useful parts of CPAN, the
